@@ -2,7 +2,7 @@ package Workflow;
 
 use warnings;
 use strict;
-use 5.006; # warnings
+use v5.14.0; # warnings
 use base qw( Workflow::Base );
 use Log::Log4perl qw( get_logger );
 use Workflow::Context;
@@ -16,7 +16,7 @@ my @FIELDS   = qw( id type description state last_update time_zone );
 my @INTERNAL = qw( _factory _observers );
 __PACKAGE__->mk_accessors( @FIELDS, @INTERNAL );
 
-$Workflow::VERSION = '1.57';
+$Workflow::VERSION = '1.58';
 
 use constant NO_CHANGE_VALUE => 'NOCHANGE';
 
@@ -377,7 +377,7 @@ Workflow - Simple, flexible system to implement workflows
 
 =head1 VERSION
 
-This documentation describes version 1.57 of Workflow
+This documentation describes version 1.58 of Workflow
 
 =head1 SYNOPSIS
 
@@ -1256,48 +1256,53 @@ The test suite can be run using, L<Module::Build>
         % ./Build test
 
 Some of the tests are reserved for the developers and are only run of the
-environment variable TEST_AUTHOR is set to true.
+environment variable C<TEST_AUTHOR> is set to true.
 
 =head1 TEST COVERAGE
 
-This is the current test coverage of Workflow version 1.32, with the TEST_AUTHOR
-flag enabled.
+This is the current test coverage of Workflow version 1.58, with the C<TEST_AUTHOR>
+flag enabled
 
-        ---------------------------- ------ ------ ------ ------ ------ ------ ------
-        File                           stmt   bran   cond    sub    pod   time  total
-        ---------------------------- ------ ------ ------ ------ ------ ------ ------
-        blib/lib/Workflow.pm           79.8   50.0   50.0   87.5  100.0    9.9   71.6
-        blib/lib/Workflow/Action.pm    90.8   66.7    n/a   88.2  100.0    4.1   89.9
-        ...flow/Action/InputField.pm   97.0   92.9   87.5  100.0  100.0    5.9   95.8
-        ...Workflow/Action/Mailer.pm  100.0    n/a    n/a  100.0  100.0    0.1  100.0
-        ...b/Workflow/Action/Null.pm  100.0    n/a    n/a  100.0  100.0    0.2  100.0
-        blib/lib/Workflow/Base.pm      96.6   86.4  100.0  100.0  100.0    9.6   95.0
-        ...lib/Workflow/Condition.pm  100.0    n/a    n/a  100.0  100.0    0.8  100.0
-        ...low/Condition/Evaluate.pm   59.0   16.7   33.3   87.5  100.0    0.9   53.0
-        ...flow/Condition/HasUser.pm   57.7    0.0    0.0   71.4  100.0    0.1   51.2
-        blib/lib/Workflow/Config.pm    96.2   81.2   33.3  100.0  100.0    6.1   92.2
-        ...b/Workflow/Config/Perl.pm   96.8   75.0   66.7  100.0  100.0    4.1   91.0
-        ...ib/Workflow/Config/XML.pm   92.3   50.0   60.0  100.0  100.0    4.9   81.4
-        blib/lib/Workflow/Context.pm  100.0    n/a    n/a  100.0  100.0    0.4  100.0
-        ...lib/Workflow/Exception.pm   89.2   50.0    n/a   91.7  100.0    3.1   89.5
-        blib/lib/Workflow/Factory.pm   86.3   61.2   37.5   92.3  100.0   19.6   75.4
-        blib/lib/Workflow/History.pm  100.0   87.5    n/a  100.0  100.0    1.8   98.1
-        ...lib/Workflow/Persister.pm   90.5   75.0   57.1   88.9  100.0    1.9   87.5
-        ...Workflow/Persister/DBI.pm   75.3   51.2   25.0   83.3  100.0    7.4   67.5
-        ...er/DBI/AutoGeneratedId.pm   77.8   40.0    n/a  100.0  100.0    0.4   70.1
-        ...ersister/DBI/ExtraData.pm   25.9    0.0    0.0   71.4  100.0    0.1   22.9
-        ...rsister/DBI/SequenceId.pm   56.2    0.0    0.0   75.0  100.0    0.3   53.1
-        ...orkflow/Persister/File.pm   94.4   48.0   33.3  100.0  100.0    2.1   83.1
-        ...low/Persister/RandomId.pm  100.0    n/a  100.0  100.0  100.0    1.8  100.0
-        ...rkflow/Persister/SPOPS.pm   89.6   50.0    n/a  100.0  100.0    0.3   85.0
-        ...orkflow/Persister/UUID.pm  100.0    n/a    n/a  100.0  100.0    0.2  100.0
-        blib/lib/Workflow/State.pm     74.4   44.2   25.0   91.7  100.0   11.0   64.3
-        ...lib/Workflow/Validator.pm  100.0  100.0    n/a  100.0  100.0    1.1  100.0
-        ...dator/HasRequiredField.pm   90.0   50.0    n/a  100.0  100.0    0.6   86.7
-        ...dator/InEnumeratedType.pm  100.0  100.0    n/a  100.0  100.0    0.4  100.0
-        ...ator/MatchesDateFormat.pm   93.3   70.0   66.7  100.0  100.0    0.8   88.2
-        Total                          83.9   54.7   39.7   93.0  100.0  100.0   76.8
-        ---------------------------- ------ ------ ------ ------ ------ ------ ------
+    TEST_AUTHOR=1 dzil cover 
+
+    ---------------------------- ------ ------ ------ ------ ------ ------ ------
+    File                           stmt   bran   cond    sub    pod   time  total
+    ---------------------------- ------ ------ ------ ------ ------ ------ ------
+    blib/lib/Workflow.pm           91.6   68.7   60.0   93.3  100.0    1.2   86.7
+    blib/lib/Workflow/Action.pm    93.5   60.0    n/a   94.1  100.0    4.4   91.4
+    ...b/Workflow/Action/Null.pm  100.0    n/a    n/a  100.0  100.0    2.3  100.0
+    blib/lib/Workflow/Base.pm      96.7   86.3   83.3  100.0  100.0    3.0   94.5
+    ...lib/Workflow/Condition.pm  100.0  100.0  100.0  100.0  100.0    4.4  100.0
+    .../Condition/CheckReturn.pm   71.7   35.7    n/a  100.0  100.0    0.0   67.6
+    ...low/Condition/Evaluate.pm   96.7   75.0    n/a  100.0  100.0    3.4   95.4
+    ...low/Condition/GreedyOR.pm  100.0  100.0    n/a  100.0  100.0    0.0  100.0
+    ...flow/Condition/HasUser.pm   70.0    n/a   33.3   83.3  100.0    0.0   70.0
+    ...flow/Condition/LazyAND.pm  100.0  100.0    n/a  100.0  100.0    0.0  100.0
+    ...kflow/Condition/LazyOR.pm  100.0  100.0    n/a  100.0  100.0    0.0  100.0
+    ...flow/Condition/Negated.pm  100.0    n/a    n/a  100.0  100.0    0.0  100.0
+    blib/lib/Workflow/Config.pm    96.2   81.2   33.3  100.0  100.0    3.1   92.2
+    ...b/Workflow/Config/Perl.pm   96.1   83.3   66.6   92.8  100.0    0.1   92.9
+    ...ib/Workflow/Config/XML.pm   94.1   62.5   50.0  100.0  100.0    4.6   90.2
+    blib/lib/Workflow/Context.pm  100.0    n/a    n/a  100.0  100.0    2.3  100.0
+    ...lib/Workflow/Exception.pm  100.0  100.0    n/a  100.0  100.0    0.9  100.0
+    blib/lib/Workflow/Factory.pm   87.4   79.3   61.5   84.6  100.0   30.9   84.3
+    blib/lib/Workflow/History.pm  100.0   87.5    n/a  100.0  100.0    4.3   98.2
+    ...ib/Workflow/InputField.pm   98.6   96.1   87.5  100.0  100.0    2.5   97.6
+    ...lib/Workflow/Persister.pm   98.4  100.0   71.4   94.7  100.0    2.4   96.4
+    ...Workflow/Persister/DBI.pm   86.7   72.0   35.2   90.6  100.0    7.7   83.0
+    ...er/DBI/AutoGeneratedId.pm   91.8   75.0   83.3  100.0  100.0    0.0   88.7
+    ...ersister/DBI/ExtraData.pm   29.8    0.0    0.0   60.0  100.0    0.6   29.7
+    ...rsister/DBI/SequenceId.pm  100.0    n/a   50.0  100.0  100.0    0.0   98.0
+    ...orkflow/Persister/File.pm   94.4   50.0   33.3  100.0  100.0    0.2   88.5
+    ...low/Persister/RandomId.pm  100.0    n/a  100.0  100.0  100.0    2.3  100.0
+    ...orkflow/Persister/UUID.pm  100.0    n/a    n/a  100.0  100.0    2.2  100.0
+    blib/lib/Workflow/State.pm     88.1   62.5   16.6   96.3  100.0    4.9   81.7
+    ...lib/Workflow/Validator.pm  100.0   83.3    n/a  100.0  100.0    2.4   97.5
+    ...dator/HasRequiredField.pm   90.9   50.0    n/a  100.0  100.0    2.3   87.8
+    ...dator/InEnumeratedType.pm  100.0  100.0    n/a  100.0  100.0    2.3  100.0
+    ...ator/MatchesDateFormat.pm  100.0  100.0  100.0  100.0  100.0    4.0  100.0
+    Total                          90.7   73.6   57.6   94.9  100.0  100.0   87.8
+    ---------------------------- ------ ------ ------ ------ ------ ------ ------
 
 Activities to get improved coverage are ongoing.
 
@@ -1400,7 +1405,7 @@ L<http://www.slideshare.net/jonasbn/workflow-yapceu2010>
 =head1 COPYRIGHT
 
 Copyright (c) 2003 Chris Winters and Arvato Direct;
-Copyright (c) 2004-2021 Chris Winters. All rights reserved.
+Copyright (c) 2004-2022 Chris Winters. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
