@@ -2,7 +2,7 @@ package TestApp::CustomWorkflow;
 
 use warnings;
 use strict;
-use 5.006;
+use v5.14.0;
 use base qw( Workflow );
 
 $TestApp::CustomWorkflow::VERSION = '0.01';
